SimpleFitsCollection
====================

.. currentmodule:: toasty.collection

.. autoclass:: SimpleFitsCollection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SimpleFitsCollection.descriptions
      ~SimpleFitsCollection.export_simple
      ~SimpleFitsCollection.images

   .. rubric:: Methods Documentation

   .. automethod:: descriptions
   .. automethod:: export_simple
   .. automethod:: images
